/*
** Copyright (C) 10 Feb 1999 Jonas Munsin <jmunsin@iki.fi>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <locale.h>

#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
       
#include <getopt.h>

#include "cdlabel.h"
#include "common_gtk.h"
#include "config_files.h"
#include "mainwindow.h"
#include "globals.h"

void exit_program(void) {
	if (0 != cdlabel_tmp_out[0])
		if (0 != remove(cdlabel_tmp_out))
			g_warning("%s::%i: could not remove cdlabelgen ps temp-file %s",
					__FILE__, __LINE__, cdlabel_tmp_out);
	if (0 != cdlabel_tmp_items[0])
		if (0 != remove(cdlabel_tmp_items))
			g_warning("%s::%i: gcombust.c::exit_program: could not remove cdlabelgen items temp-file %s",
					__FILE__, __LINE__, cdlabel_tmp_items);
	g_free(mainptr);
	gtk_main_quit();
}

static char *initial_selection_path = NULL;

static void do_args(int argc, char *argv[]) {
	int c;

	while (1) {
		static struct option long_options[] = {
			{"help", 0, NULL, 'h'},
			{"load-selection", 1, NULL, 'l'},
			{"version", 0, NULL, 'v'},
			{0, 0, 0, 0}
		};
		c = getopt_long(argc, argv, "hl:v", long_options, NULL);
		if (-1 == c)
			break;
		switch (c) {
			case 'h':
				printf(_("Usage: gcombust [OPTION]\n"
							"-h --help\t\tdisplay this help and exit\n"
							"-l --load-selection\tload saved selection from file\n"
							"-v --version\t\tdisplay version information and exit\n"));
				exit(0);
				break;
			case 'l':
				initial_selection_path = optarg;
				break;
			case 'v':
				printf(VERSION_INFO_STRING, VERSION);
				printf("\n");
				exit(0);
				break;
			case '?':
				printf(_("See \"gcombust --help\" for more information\n"));
				break;
			default:
				g_warning("%s::%i: getopt returned %c", __FILE__, __LINE__, c);
				break;
		}
	}
	if (optind < argc) {
		printf("unrecognized argument:\n");
		while (optind < argc)
			printf ("%s ", argv[optind++]);
		printf ("\n");
	}
}

int main (int argc, char *argv[]) {
	gtk_set_locale(); /* gtk_set_locale calls setlocale last time I checked the
				 * gtk source */
	bindtextdomain(PACKAGE, LOCALEDIR);
	textdomain(PACKAGE);
	gtk_init(&argc, &argv);

	do_args(argc, argv);

	setup_everything();

	read_config_file();

	if (NULL != initial_selection_path)
		load_selection(initial_selection_path);

	gtk_main();

	return 0;
}

